==> identity-apps-1.0.117-source-release.zip: identity-apps-1.0.117/modules/i18n/src/translations/en-US/portals/common.ts <==
/**
 * Copyright (c) 2020, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import { CommonNS } from "../../../models";

export const common: CommonNS = {
    access: "Access",
    active: "Active",
    add: "Add",
    all: "All",
    applicationName: "Application name",
    applications: "Applications",
    approvalStatus: "Approval Status",
    approve: "Approve",
    assignees: "Assignees",
    browser: "Browser",
    cancel: "Cancel",
    challengeQuestionNumber: "Challenge Question {{number}}",
    change: "Change",
    claim: "Claim",
    completed: "Completed",
    configure: "Configure",
    contains: "Contains",
    continue: "Continue",
    createdOn: "Created on",
    dangerZone: "Danger Zone",
    delete: "Delete",
    description: "Description",
    deviceModel: "Device model",
    edit: "Edit",
    endsWith: "Ends with",
    equals: "Equals",
    filter: "Filter",
    goBackHome: "Go back home",
    help: "Help",
    hidePassword: "Hide password",
    initiator: "Initiator",
    ipAddress: "ip address",
    lastAccessed: "Last accessed",
    lastSeen: "Last seen",
    loginTime: "Login time",
    logout: "Logout",
    more: "More",
    name: "Name",
    operatingSystem: "Operating System",
    operations: "Operations",
    overview: "Overview",
    personalInfo: "Personal Info",
    priority: "Priority",
    privacy: "Privacy",
    properties: "Properties",
    ready: "Ready",
    reject: "Reject",
    release: "Release",
    remove: "Remove",
    removeAll: "Remove all",
    reserved: "Reserved",
    resetFilters: "Reset filters",
    retry: "Retry",
    revoke: "Revoke",
    revokeAll: "Revoke all",
    save: "Save",
    search: "Search",
    security: "Security",
    showAll: "Show all",
    showLess: "Show less",
    showMore: "Show more",
    showPassword: "Show password",
    startsWith: "Starts with",
    submit: "Submit",
    switch: "Switch",
    terminate: "Terminate",
    terminateAll: "Terminate all",
    terminateSession: "Terminate session",
    type: "Type",
    update: "Update",
    user: "User"
};

==> identity-apps-1.0.217-source-release.zip: identity-apps-1.0.217/modules/i18n/src/translations/en-US/portals/common.ts <==
/**
 * Copyright (c) 2020, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import { CommonNS } from "../../../models";

export const common: CommonNS = {
    access: "Access",
    active: "Active",
    add: "Add",
    all: "All",
    applicationName: "Application name",
    applications: "Applications",
    approvalStatus: "Approval Status",
    approve: "Approve",
    assignees: "Assignees",
    browser: "Browser",
    cancel: "Cancel",
    challengeQuestionNumber: "Challenge Question {{number}}",
    change: "Change",
    claim: "Claim",
    close: "Close",
    completed: "Completed",
    configure: "Configure",
    contains: "Contains",
    continue: "Continue",
    createdOn: "Created on",
    dangerZone: "Danger Zone",
    delete: "Delete",
    description: "Description",
    deviceModel: "Device model",
    docs: "Docs",
    documentation: "Documentation",
    done: "Done",
    download: "Download",
    edit: "Edit",
    endsWith: "Ends with",
    equals: "Equals",
    filter: "Filter",
    goBackHome: "Go back home",
    help: "Help",
    hidePassword: "Hide password",
    identityProviders: "Identity Providers",
    initiator: "Initiator",
    ipAddress: "ip address",
    lastAccessed: "Last accessed",
    lastSeen: "Last seen",
    loginTime: "Login time",
    logout: "Logout",
    more: "More",
    myAccount: "My Account",
    name: "Name",
    operatingSystem: "Operating System",
    operations: "Operations",
    overview: "Overview",
    personalInfo: "Personal Info",
    pin: "Pin",
    pinned: "Pinned",
    priority: "Priority",
    privacy: "Privacy",
    properties: "Properties",
    ready: "Ready",
    reject: "Reject",
    release: "Release",
    remove: "Remove",
    removeAll: "Remove all",
    reserved: "Reserved",
    resetFilters: "Reset filters",
    retry: "Retry",
    revoke: "Revoke",
    revokeAll: "Revoke all",
    samples: "Samples",
    save: "Save",
    services: "Services",
    sdks: "SDKs",
    search: "Search",
    security: "Security",
    showAll: "Show all",
    showLess: "Show less",
    showMore: "Show more",
    showPassword: "Show password",
    startsWith: "Starts with",
    submit: "Submit",
    switch: "Switch",
    technologies: "Technologies",
    terminate: "Terminate",
    terminateAll: "Terminate all",
    terminateSession: "Terminate session",
    type: "Type",
    unpin: "Unpin",
    unpinned: "Unpinned",
    update: "Update",
    user: "User",
    verify: "Verify"
};
